#
# spec file for package xmgrace
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xmgrace
Version:        5.1.25
Release:        4.7
Summary:        A 2D-Plot-Program for Visualisation of Scientific Data
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://plasma-gate.weizmann.ac.il/Grace/
Source:         https://ftp.fu-berlin.de/unix/graphics/grace/src/grace5/grace-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        xmgrace.png
Patch0:         xmgrace-null.patch
Patch1:         xmgrace-strip.patch
Patch2:         xmgrace-help.patch
Patch3:         reproducible.patch
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  openmotif-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xt)

%description
Grace is a WYSIWYG 2D plotting tool for the X Window System and M*tif.
Grace is a descendant of ACE/gr, also known as Xmgr. It knows a lot of
different graph types and supports a lot of output formats.

For examples, see %{_prefix}/lib/xmgrace/examples.

%package devel
Summary:        Grace library
Group:          Productivity/Graphics/Visualization/Graph

%description devel
Grace is a WYSIWYG 2D plotting tool for the X Window System and M*tif.
Grace is a descendant of ACE/gr, also known as Xmgr. It knows a lot of
different graph types and supports a lot of output formats. This devel
package contains a library to work with grace from other applications.

For further information consult the main package.

%prep
%setup -q -n grace-%{version}
%patch0
%patch1
%patch2
%patch3 -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%configure \
  --enable-grace-home=%{_libdir}/xmgrace \
  --with-helpviewer="%{_bindir}/desktop-launch %{s}"
make %{?_smp_mflags}

%install
%make_install
make DESTDIR=%{buildroot} install links
mkdir -p %{buildroot}/%{_defaultdocdir}/xmgrace
rm -rf %{buildroot}%{_prefix}/man
mkdir -p %{buildroot}%{_mandir}/man1
rm -f %{buildroot}%{_mandir}/man1/*.1
mv %{buildroot}%{_libdir}/xmgrace/doc/*.1 %{buildroot}%{_mandir}/man1
mv %{buildroot}%{_libdir}/xmgrace/doc %{buildroot}/%{_defaultdocdir}/xmgrace
%if "%{_lib}" == "lib64"
mv %{buildroot}%{_prefix}/lib/libgrace_np.a %{buildroot}%{_libdir}
%endif
cp CHANGES COPYRIGHT ChangeLog DEVELOPERS LICENSE README %{buildroot}/%{_defaultdocdir}/xmgrace
install -dm 755 %{buildroot}/%{_datadir}/pixmaps
install %{SOURCE2} -m 644 %{buildroot}/%{_datadir}/pixmaps
install -dm 755 %{buildroot}%{_datadir}/applications/
install %{SOURCE1} -m 644 %{buildroot}%{_datadir}/applications/
%suse_update_desktop_file -r %{buildroot}%{_datadir}/applications/xmgrace.desktop Education Science Math

%files
%license LICENSE
%doc %{_defaultdocdir}/xmgrace
%{_mandir}/man1/*
%{_libdir}/xmgrace
%{_bindir}/gracebat
%{_bindir}/xmgrace
%{_bindir}/grace
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*png

%files -n xmgrace-devel
%license LICENSE
%{_includedir}/grace_np.h
%{_libdir}/libgrace_np.a

%changelog
* Thu May 19 2022 Marcus Meissner <meissner@suse.com>
- switched urls to https
* Mon Sep  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects to build xmgrace.
- Run spec-cleaner
* Thu May  4 2017 bwiedemann@suse.com
- Add reproducible.patch to make build fully reproducible
* Sun Mar 15 2015 freitag@opensuse.org
- update to version 5.1.25, changes
  * [ES] killing set data from GUI and scripts now clears set comments
  * [ES] undid "always overwrite set comments when reading data in" from 5.1.24
  * [ES] fixed Fourier transform DC-term amplitude (rep. #630)
  * [ES] newer versions of "make" tried to regenerate documentation (rep. #2240)
  * [ES] fixed detection of dynamic loading libraries (rep. #2238)
  * [ES] install PDF docs instead of the DVI ones
  * [ES] added cephes/COPYING (from Debian)
  * [ES] a workaround for broken input of non-ASCII text under UTF8 locales
  * [ES] always overwrite set comments when reading data in
* Mon Mar  9 2015 dimstar@opensuse.org
- Change categories to 'Education;Science;Math;', as 'Edutainmnent'
  is no longer valid.
* Fri Sep 13 2013 mvyskocil@suse.com
- Drop t1lib from buildrequires, no longer in Factory
* Tue Jul 23 2013 tchvatal@suse.com
- Use openmotif-devel so we work on other releases.
* Tue Jul 23 2013 tchvatal@suse.com
- Fix the configure phase by adding missing BuildRequires.
* Thu Jul 18 2013 coolo@suse.com
- fix download url
* Thu Feb 28 2013 matwey.kornilov@gmail.com
- update to version 5.1.23, changes
  * removed *86 specific optimizations (rep. #2154)
  * renamed RMS per cent error -> relative error (rep. #2192)
  * a workaround for a bug in recent Xorg not releasing grab of popup menus
  * accept -graphtype chart instead of bar. List possible values in the help output
  * a grace_np fix
  * IsoLatin5.enc was not included in the distribution
- Drop xmgrace-libpng15.patch: This patch is in upstream now.
* Tue Sep  4 2012 pgajdos@suse.com
- builds also with libpng15
  * libpng15.patch
* Wed Mar 28 2012 cfarrell@suse.com
- license update: GPL-2.0+
  SPDX format
* Tue Nov 10 2009 freitag@novell.com
- update to version 5.1.22 as a maintenance update to 5.1.21
  splitted devel package with the grace lib
* Thu Jul 19 2007 stbinner@suse.de
- fix suse_update_desktop_file call
* Sat May 12 2007 aj@suse.de
- Use lib64 if appropriate.
* Thu Apr 26 2007 freitag@suse.de
- update to version 5.1.21 - minor improvements
- Bugzilla #117995: Fixed help path
- Bugzilla #106119: Fixed desktop file
* Wed Jan 24 2007 sndirsch@suse.de
- /usr/X11R6 --> /usr
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 freitag@suse.de
- update to version 5.1.19
  It is a maintenance release of the 5.1 series; an upgrade is
  recommended.
* Mon Jan 16 2006 schwab@suse.de
- Don't strip binaries.
- Fix libdir.
* Fri Jan  6 2006 stbinner@suse.de
- fix file list
* Sun Oct  2 2005 stbinner@suse.de
- fix typo in GenericName entry of .desktop file
* Mon Apr 25 2005 meissner@suse.de
- fixed 2 character overflow due to small stack buffer.
* Wed Feb 23 2005 meissner@suse.de
- one 0 -> NULL in a XtVa call.
* Wed Jan 19 2005 freitag@suse.de
- update to version 5.1.18, maintenance release
* Thu Feb  5 2004 freitag@suse.de
- update to version 5.1.14, minor feature enhancements and bugfixes.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Wed Jun 11 2003 ro@suse.de
- install man-pages to X11R6/man/man1
* Wed May  7 2003 freitag@suse.de
- update to version 5.1.12, new features, bugfixes etc.
* Mon Nov  4 2002 freitag@suse.de
- update to version 5.1.10, which brought a lot of new features,
  bugfixes etc. See CHANGES-file for details.
* Fri Jul 26 2002 freitag@suse.de
- update to version 5.1.8:
  [ES] implemented (and enabled by default) "safe" mode, in which statements
    of the command language which may result in file modifications are
    disabled. This is to prevent execution of such commands contained in
    potentially malicious project files acquired from untrusted sources
  [ES] use leading zeros in axis year formats so to make up to 2 or 4
    digits in total (depending on whether the two-digit year span is
    enabled in the project preferences)
  [ES] simplified X initialization - the resolution detection introduced
    in 5.1.5 prevented Grace from starting up with some buggy X servers
    (notably, StarNet's X-win32) (rep. #1138)
  [ES] -safe/-nosafe command line options for switching the safe mode
  [ES] "Run in safe mode" checkbox in "Edit/Preferences" for the same
    purpose
  [ES] removed broken "Command" function of the hotlink popup
* Tue May 21 2002 freitag@suse.de
- update to version 5.1.7:
  [ES] allow XYZ sets in polar graphs
  [ES] allow defining string columns when creating sets from block data
    via the command line or parser, e.g. -bxy "1:2:{3}" (rep. #978)
  [ES] honour symskip for all set types (it wasn't for BAR, BARDY,
    BARDYDY, XYHILO, XYR, XYVMAP, and BOXPLOT)
  [ES] extended x-correlation routines to calculate x-covariance if desired
  [ES] implemented optional snake-like matrix fill in graph arranging
    (rep. #1119)
  and other bugfixes, enhancements.
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Nov 28 2001 freitag@suse.de
- update to version 5.1.5, maintenance release with bugfixes
* Wed Aug 22 2001 ro@suse.de
- removed pdflib from neededforbuild (for license problems)
* Mon Jul 23 2001 freitag@suse.de
- update to version 5.1.4
* Tue Apr 10 2001 freitag@suse.de
- update to version 5.1.3
* Thu Nov 23 2000 freitag@suse.de
- new version 5.1.2
* Sat Nov 18 2000 kukuk@suse.de
- Link against OpenMotif
* Wed Sep  6 2000 freitag@suse.de
- updated to version 5.1.1
* Wed May 10 2000 freitag@suse.de
- updated to version 5.1.0 with pdf-support, netcdf etc.
- documentation patch updated
* Tue Feb  8 2000 freitag@suse.de
- updated specfile with %%{version}, group etc.
* Tue Oct 26 1999 freitag@suse.de
- new version 5.0.5
